# QMK CLI

A program to help users work with [QMK Firmware](https://qmk.fm/).

# Features

* Interact with your qmk_firmware tree from any location
* Use `qmk clone` to pull down anyone's `qmk_firmware` fork
* Setup your build environment with `qmk setup`
* Check that your environment is correctly setup with `qmk doctor`
* Dispatches to `qmk_firmware/bin/qmk` for additional functionality:
    * `qmk compile-json`
    * More to come

# Quickstart

To be written.
